@@ -12,6 +12,7 @@
 
 #include "php_psr.h"
 #include "psr_log.h"
+#include "psr_private.h"
 
 /* Needed to work around https://bugs.php.net/bug.php?id=69579 */
 #define PHP_PSR_EXTRA_TRAIT_FLAGS ZEND_ACC_ARENA_ALLOCATED
@@ -19,25 +20,22 @@
 /* {{{ Psr\Log\InvalidArgumentException */
 
 PHP_PSR_API zend_class_entry * PsrLogInvalidArgumentException_ce_ptr;
+#define PsrLogInvalidArgumentException_methods NULL
 
 static zend_always_inline void php_psr_register_InvalidArgumentException(INIT_FUNC_ARGS)
 {
-    zend_class_entry ce;
-    INIT_CLASS_ENTRY(ce, "Psr\\Log\\InvalidArgumentException", NULL);
-    PsrLogInvalidArgumentException_ce_ptr = zend_register_internal_class_ex(&ce, spl_ce_InvalidArgumentException);
+    PHP_PSR_REGISTER_CLASS(Log, InvalidArgumentException, spl_ce_InvalidArgumentException);
 }
 
 /* }}} Psr\Log\InvalidArgumentException */
 /* {{{ Psr\Log\LogLevel */
 
 PHP_PSR_API zend_class_entry * PsrLogLogLevel_ce_ptr;
+#define PsrLogLogLevel_methods NULL
 
 static zend_always_inline void php_psr_register_LogLevel(INIT_FUNC_ARGS)
 {
-    zend_class_entry ce;
-
-    INIT_CLASS_ENTRY(ce, "Psr\\Log\\LogLevel", NULL);
-    PsrLogLogLevel_ce_ptr = zend_register_internal_class(&ce);
+    PHP_PSR_REGISTER_CLASS(Log, LogLevel, NULL);
 
     REGISTER_PSR_CLASS_CONST_STRING(PsrLogLogLevel_ce_ptr, "EMERGENCY", "emergency");
     REGISTER_PSR_CLASS_CONST_STRING(PsrLogLogLevel_ce_ptr, "ALERT", "alert");
@@ -56,22 +54,21 @@ static zend_always_inline void php_psr_register_LogLevel(INIT_FUNC_ARGS)
 PHP_PSR_API zend_class_entry * PsrLogLoggerInterface_ce_ptr;
 
 static zend_function_entry PsrLogLoggerInterface_methods[] = {
-    PHP_PSR_ABSTRACT_ME(PsrLogLoggerInterface, emergency)
-    PHP_PSR_ABSTRACT_ME(PsrLogLoggerInterface, alert)
-    PHP_PSR_ABSTRACT_ME(PsrLogLoggerInterface, critical)
-    PHP_PSR_ABSTRACT_ME(PsrLogLoggerInterface, error)
-    PHP_PSR_ABSTRACT_ME(PsrLogLoggerInterface, warning)
-    PHP_PSR_ABSTRACT_ME(PsrLogLoggerInterface, notice)
-    PHP_PSR_ABSTRACT_ME(PsrLogLoggerInterface, info)
-    PHP_PSR_ABSTRACT_ME(PsrLogLoggerInterface, debug)
-    PHP_PSR_ABSTRACT_ME(PsrLogLoggerInterface, log)
+    PHP_PSR_ABSTRACT_ME(Log, LoggerInterface, emergency)
+    PHP_PSR_ABSTRACT_ME(Log, LoggerInterface, alert)
+    PHP_PSR_ABSTRACT_ME(Log, LoggerInterface, critical)
+    PHP_PSR_ABSTRACT_ME(Log, LoggerInterface, error)
+    PHP_PSR_ABSTRACT_ME(Log, LoggerInterface, warning)
+    PHP_PSR_ABSTRACT_ME(Log, LoggerInterface, notice)
+    PHP_PSR_ABSTRACT_ME(Log, LoggerInterface, info)
+    PHP_PSR_ABSTRACT_ME(Log, LoggerInterface, debug)
+    PHP_PSR_ABSTRACT_ME(Log, LoggerInterface, log)
     PHP_FE_END
 };
 
-static zend_always_inline void php_psr_register_LoggerInterface(INIT_FUNC_ARGS) {
-    zend_class_entry ce;
-    INIT_CLASS_ENTRY(ce, "Psr\\Log\\LoggerInterface", PsrLogLoggerInterface_methods);
-    PsrLogLoggerInterface_ce_ptr = zend_register_internal_interface(&ce);
+static zend_always_inline void php_psr_register_LoggerInterface(INIT_FUNC_ARGS)
+{
+    PHP_PSR_REGISTER_INTERFACE(Log, LoggerInterface);
 }
 
 /* }}} Psr\Log\LoggerInterface */
@@ -80,15 +77,13 @@ static zend_always_inline void php_psr_register_LoggerInterface(INIT_FUNC_ARGS)
 PHP_PSR_API zend_class_entry * PsrLogLoggerAwareInterface_ce_ptr;
 
 static zend_function_entry PsrLogLoggerAwareInterface_methods[] = {
-    PHP_PSR_ABSTRACT_ME(PsrLogLoggerAwareInterface, setLogger)
+    PHP_PSR_ABSTRACT_ME(Log, LoggerAwareInterface, setLogger)
     PHP_FE_END
 };
 
 static zend_always_inline void php_psr_register_LoggerAwareInterface(INIT_FUNC_ARGS)
 {
-    zend_class_entry ce;
-    INIT_CLASS_ENTRY(ce, "Psr\\Log\\LoggerAwareInterface", PsrLogLoggerAwareInterface_methods);
-    PsrLogLoggerAwareInterface_ce_ptr = zend_register_internal_interface(&ce);
+    PHP_PSR_REGISTER_INTERFACE(Log, LoggerAwareInterface);
 }
 
 /* }}} Psr\Log\LoggerAwareInterface */
@@ -183,9 +178,7 @@ static zend_function_entry PsrLogAbstractLogger_methods[] = {
 
 static zend_always_inline void php_psr_register_AbstractLogger(INIT_FUNC_ARGS)
 {
-    zend_class_entry ce;
-    INIT_CLASS_ENTRY(ce, "Psr\\Log\\AbstractLogger", PsrLogAbstractLogger_methods);
-    PsrLogAbstractLogger_ce_ptr = zend_register_internal_class(&ce);
+    PHP_PSR_REGISTER_CLASS(Log, AbstractLogger, NULL);
     zend_class_implements(PsrLogAbstractLogger_ce_ptr, 1, PsrLogLoggerInterface_ce_ptr);
 }
 
@@ -206,9 +199,7 @@ static zend_function_entry PsrLogNullLogger_methods[] = {
 
 static zend_always_inline void php_psr_register_NullLogger(INIT_FUNC_ARGS)
 {
-    zend_class_entry ce;
-    INIT_CLASS_ENTRY(ce, "Psr\\Log\\NullLogger", PsrLogNullLogger_methods);
-    PsrLogNullLogger_ce_ptr = zend_register_internal_class_ex(&ce, PsrLogAbstractLogger_ce_ptr);
+    PHP_PSR_REGISTER_CLASS(Log, NullLogger, PsrLogAbstractLogger_ce_ptr);
 }
 
 /* }}} Psr\Log\NullLogger */
@@ -231,9 +222,7 @@ static zend_function_entry PsrLogLoggerTrait_methods[] = {
 
 static zend_always_inline void php_psr_register_LoggerTrait(INIT_FUNC_ARGS)
 {
-    zend_class_entry ce;
-    INIT_CLASS_ENTRY(ce, "Psr\\Log\\LoggerTrait", PsrLogLoggerTrait_methods);
-    PsrLogLoggerTrait_ce_ptr = zend_register_internal_class(&ce);
+    PHP_PSR_REGISTER_CLASS(Log, LoggerTrait, NULL);
     PsrLogLoggerTrait_ce_ptr->ce_flags |= ZEND_ACC_TRAIT;
 }
 
@@ -265,10 +254,7 @@ static zend_function_entry PsrLogLoggerAwareTrait_methods[] = {
 
 static zend_always_inline void php_psr_register_LoggerAwareTrait(INIT_FUNC_ARGS)
 {
-    zend_class_entry ce;
-    INIT_CLASS_ENTRY(ce, "Psr\\Log\\LoggerAwareTrait", PsrLogLoggerAwareTrait_methods);
-    //ce.ce_flags |= ZEND_ACC_TRAIT;
-    PsrLogLoggerAwareTrait_ce_ptr = zend_register_internal_class(&ce);
+    PHP_PSR_REGISTER_CLASS(Log, LoggerAwareTrait, NULL);
     PsrLogLoggerAwareTrait_ce_ptr->ce_flags |= ZEND_ACC_TRAIT;
     zend_declare_property_null(PsrLogLoggerAwareTrait_ce_ptr, "logger", sizeof("logger")-1, ZEND_ACC_PROTECTED);
 }
